yakumo.constant

Package yakumo :: Module constant |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.constant

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #   Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #   not use this file except in compliance with the License. You may obtain
     6  #   a copy of the License at
     7  #
     8  #       http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #   Unless required by applicable law or agreed to in writing, software
    11  #   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #   License for the specific language governing permissions and limitations
    14  #   under the License.
    15
    16  """
    17  Constants
    18  """
    19
    20  UNDEF = '__UNDEF__'
    21